@@ -2,8 +2,8 @@ import os
 
 initpy = '''import json
 
-functionformat = def {funcname}():\n"
-textformat = "\tprint(\"{text}\")\n\tinput()\n"
+functionformat = "def {funcname}():\\n"
+textformat = "\\tprint(\\"{text}\\")\\n\\tinput()\\n"
 
 f = open("engine/textdump.json", "rt")
 
